aurorawatchuk
=============

A Python interface to the AuroraWatch UK API.

Installation
------------

The easiest way to install the module is with ``pip``::

    pip install aurorawatchuk

Developers may wish to clone the git repository and install it in developer mode::

    git clone https://github.com/stevemarple/python-aurorawatchuk.git
    cd python-aurorawatchuk
    python setup.py develop

Using the module
----------------

A short tutorial describing how to use the module is available as an ipython notebook from
https://github.com/stevemarple/python-aurorawatchuk/blob/master/aurorawatchuk/examples/aurorawatchuk_api.ipynb



